perllib
=======

.. toctree::
   :maxdepth: 4

   perllib

charnames
=========

.. toctree::
   :maxdepth: 4

   charnames

Config
======

.. toctree::
   :maxdepth: 4

   Config

Math
====

.. toctree::
   :maxdepth: 4

   Math

Sys
===

.. toctree::
   :maxdepth: 4

   Sys

File
====

.. toctree::
   :maxdepth: 4

   File

FindBin
=======

.. toctree::
   :maxdepth: 4

   FindBin
